package cn.com.infosec.ocsp;

import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.nist.NISTObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.teletrust.TeleTrusTObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import cn.com.infosec.util.Strings;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Set;

class OCSPUtil {
   private static Hashtable algorithms = new Hashtable();
   private static Hashtable oids = new Hashtable();
   private static Set noParams = new HashSet();

   static {
      DERObjectIdentifier var0 = PKCSObjectIdentifiers.md2WithRSAEncryption;
      algorithms.put("MD2WITHRSAENCRYPTION", var0);
      algorithms.put("MD2WITHRSA", var0);
      DERObjectIdentifier var1 = PKCSObjectIdentifiers.md5WithRSAEncryption;
      algorithms.put("MD5WITHRSAENCRYPTION", var1);
      algorithms.put("MD5WITHRSA", var1);
      DERObjectIdentifier var2 = PKCSObjectIdentifiers.sha1WithRSAEncryption;
      algorithms.put("SHA1WITHRSAENCRYPTION", var2);
      algorithms.put("SHA1WITHRSA", var2);
      DERObjectIdentifier var3 = PKCSObjectIdentifiers.sha224WithRSAEncryption;
      algorithms.put("SHA224WITHRSAENCRYPTION", var3);
      algorithms.put("SHA224WITHRSA", var3);
      DERObjectIdentifier var4 = PKCSObjectIdentifiers.sha256WithRSAEncryption;
      algorithms.put("SHA256WITHRSAENCRYPTION", var4);
      algorithms.put("SHA256WITHRSA", var4);
      DERObjectIdentifier var5 = PKCSObjectIdentifiers.sha384WithRSAEncryption;
      algorithms.put("SHA384WITHRSAENCRYPTION", var5);
      algorithms.put("SHA384WITHRSA", var5);
      DERObjectIdentifier var6 = PKCSObjectIdentifiers.sha512WithRSAEncryption;
      algorithms.put("SHA512WITHRSAENCRYPTION", var6);
      algorithms.put("SHA512WITHRSA", var6);
      DERObjectIdentifier var7 = TeleTrusTObjectIdentifiers.rsaSignatureWithripemd160;
      algorithms.put("RIPEMD160WITHRSAENCRYPTION", var7);
      algorithms.put("RIPEMD160WITHRSA", var7);
      DERObjectIdentifier var8 = TeleTrusTObjectIdentifiers.rsaSignatureWithripemd128;
      algorithms.put("RIPEMD128WITHRSAENCRYPTION", var8);
      algorithms.put("RIPEMD128WITHRSA", var8);
      DERObjectIdentifier var9 = TeleTrusTObjectIdentifiers.rsaSignatureWithripemd256;
      algorithms.put("RIPEMD256WITHRSAENCRYPTION", var9);
      algorithms.put("RIPEMD256WITHRSA", var9);
      DERObjectIdentifier var10 = X9ObjectIdentifiers.id_dsa_with_sha1;
      algorithms.put("SHA1WITHDSA", var10);
      algorithms.put("DSAWITHSHA1", var10);
      DERObjectIdentifier var11 = NISTObjectIdentifiers.dsa_with_sha224;
      algorithms.put("SHA224WITHDSA", var11);
      DERObjectIdentifier var12 = NISTObjectIdentifiers.dsa_with_sha256;
      algorithms.put("SHA256WITHDSA", var12);
      DERObjectIdentifier var13 = X9ObjectIdentifiers.ecdsa_with_SHA1;
      algorithms.put("SHA1WITHECDSA", var13);
      algorithms.put("ECDSAWITHSHA1", var13);
      DERObjectIdentifier var14 = X9ObjectIdentifiers.ecdsa_with_SHA224;
      algorithms.put("SHA224WITHECDSA", var14);
      DERObjectIdentifier var15 = X9ObjectIdentifiers.ecdsa_with_SHA256;
      algorithms.put("SHA256WITHECDSA", var15);
      DERObjectIdentifier var16 = X9ObjectIdentifiers.ecdsa_with_SHA384;
      algorithms.put("SHA384WITHECDSA", var16);
      DERObjectIdentifier var17 = X9ObjectIdentifiers.ecdsa_with_SHA512;
      algorithms.put("SHA512WITHECDSA", var17);
      DERObjectIdentifier var18 = CryptoProObjectIdentifiers.gostR3411_94_with_gostR3410_94;
      algorithms.put("GOST3411WITHGOST3410", var18);
      algorithms.put("GOST3411WITHGOST3410-94", var18);
      oids.put(var0, "MD2WITHRSA");
      oids.put(var1, "MD5WITHRSA");
      oids.put(var2, "SHA1WITHRSA");
      oids.put(var3, "SHA224WITHRSA");
      oids.put(var4, "SHA256WITHRSA");
      oids.put(var5, "SHA384WITHRSA");
      oids.put(var6, "SHA512WITHRSA");
      oids.put(var7, "RIPEMD160WITHRSA");
      oids.put(var8, "RIPEMD128WITHRSA");
      oids.put(var9, "RIPEMD256WITHRSA");
      oids.put(var10, "SHA1WITHDSA");
      oids.put(var11, "SHA224WITHDSA");
      oids.put(var12, "SHA256WITHDSA");
      oids.put(var13, "SHA1WITHECDSA");
      oids.put(var14, "SHA224WITHECDSA");
      oids.put(var15, "SHA256WITHECDSA");
      oids.put(var16, "SHA384WITHECDSA");
      oids.put(var17, "SHA512WITHECDSA");
      oids.put(var18, "GOST3411WITHGOST3410");
      noParams.add(var13);
      noParams.add(var14);
      noParams.add(var15);
      noParams.add(var16);
      noParams.add(var17);
      noParams.add(var10);
      noParams.add(var11);
      noParams.add(var12);
   }

   static DERObjectIdentifier getAlgorithmOID(String algorithmName) {
      algorithmName = Strings.toUpperCase(algorithmName);
      return algorithms.containsKey(algorithmName) ? (DERObjectIdentifier)algorithms.get(algorithmName) : new DERObjectIdentifier(algorithmName);
   }

   static String getAlgorithmName(DERObjectIdentifier oid) {
      return oids.containsKey(oid) ? (String)oids.get(oid) : oid.getId();
   }

   static AlgorithmIdentifier getSigAlgID(DERObjectIdentifier sigOid) {
      if (noParams.contains(sigOid)) {
         return new AlgorithmIdentifier(sigOid);
      } else {
         DERNull var1;
         var1 = new DERNull.<init>();
         return new AlgorithmIdentifier(sigOid, var1);
      }
   }

   static Iterator getAlgNames() {
      Enumeration var0 = algorithms.keys();
      ArrayList var1;
      var1 = new ArrayList.<init>();

      while(var0.hasMoreElements()) {
         var1.add(var0.nextElement());
      }

      return var1.iterator();
   }
}
